@@ -46,6 +46,8 @@ class Clock():
         self.text_scaling = self.gconf_client.get_float(GCONF_DIR + "/text_scaling")
         self.twelve_hour_mode = self.gconf_client.get_bool(GCONF_DIR + "/twelve_hour_mode")
 
+        self.pad_zeros = self.gconf_client.get_bool(GCONF_DIR + "/pad_zeros")
+
     def draw(self):
         self.time = datetime.today()
         self.context = self.drawing_area.window.cairo_create()
@@ -93,6 +95,8 @@ class Clock():
         self.text_scaling = self.gconf_client.get_float(GCONF_DIR + "/text_scaling")
         self.twelve_hour_mode = self.gconf_client.get_bool(GCONF_DIR + "/twelve_hour_mode")
 
+        self.pad_zeros = self.gconf_client.get_bool(GCONF_DIR + "/pad_zeros")
+
     def get_alarm_enabled(self):
         return self.alarm_enabled
 
@@ -137,6 +141,9 @@ class Clock():
             self.gconf_client.set_float(GCONF_DIR + "/text_scaling", 1.0)
             self.gconf_client.set_bool(GCONF_DIR + "/twelve_hour_mode", False)
 
+        if not self.gconf_client.get(GCONF_DIR + "/pad_zeros") :
+            self.gconf_client.set_bool(GCONF_DIR + "/pad_zeros", True)
+        
 # Currently we do not use the callback (see above).
 #        self.gconf_client.notify_add(GCONF_DIR, self.gconf_cb)
 
